diff src/symsinit.h @ 814:a634e3b7acc8

[xemacs-hg @ 2002-04-14 12:41:59 by ben] latest changes TODO.ben-mule-21-5: Update. make-docfile.c: Add basic support for handling ISO 2022 doc strings -- we parse the basic charset designation sequences so we know whether we're in ASCII and have to pay attention to end quotes and such. Reformat code according to coding standards. abbrev.el: Add `global-abbrev-mode', which turns on or off abbrev-mode in all buffers. Added `defining-abbrev-turns-on-abbrev-mode' -- if non-nil, defining an abbrev through an interactive function will automatically turn on abbrev-mode, either globally or locally depending on the command. This is the "what you'd expect" behavior. indent.el: general function for indenting a balanced expression in a mode-correct way. Works similar to indent-region in that a mode can specify a specific command to do the whole operation; if not, figure out the region using forward-sexp and indent each line using indent-according-to-mode. keydefs.el: Removed. Modify M-C-backslash to do indent-region-or-balanced-expression. Make S-Tab just insert a TAB char, like it's meant to do. make-docfile.el: Now that we're using the call-process-in-lisp, we need to load an extra file win32-native.el because we're running a bare temacs. menubar-items.el: Totally redo the Cmds menu so that most used commands appear directly on the menu and less used commands appear in submenus. The old way may have been very pretty, but rather impractical. process.el: Under Windows, don't ever use old-call-process-internal, even in batch mode. We can do processes in batch mode. subr.el: Someone recoded truncate-string-to-width, saying "the FSF version is too complicated and does lots of hard-to-understand stuff" but the resulting recoded version was *totally* wrong! it misunderstood the basic point of this function, which is work in *columns* not chars. i dumped ours and copied the version from FSF 21.1. Also added truncate-string-with-continuation-dots, since this idiom is used often. config.inc.samp, xemacs.mak: Separate out debug and optimize flags. Remove all vestiges of USE_MINIMAL_TAGBITS, USE_INDEXED_LRECORD_IMPLEMENTATION, and GUNG_HO, since those ifdefs have long been removed. Make error-checking support actually work. Some rearrangement of config.inc.samp to make it more logical. Remove callproc.c and ntproc.c from xemacs.mak, no longer used. Make pdump the default. lisp.h: Add support for strong type-checking of Bytecount, Bytebpos, Charcount, Charbpos, and others, by making them classes, overloading the operators to provide integer-like operation and carefully controlling what operations are allowed. Not currently enabled in C++ builds because there are still a number of compile errors, and it won't really work till we merge in my "8-bit-Mule" workspace, in which I make use of the new types Charxpos, Bytexpos, Memxpos, representing a "position" either in a buffer or a string. (This is especially important in the extent code.) abbrev.c, alloc.c, eval.c, buffer.c, buffer.h, editfns.c, fns.c, text.h: Warning fixes, some of them related to new C++ strict type checking of Bytecount, Charbpos, etc. dired.c: Caught an actual error due to strong type checking -- char len being passed when should be byte len. alloc.c, backtrace.h, bytecode.c, bytecode.h, eval.c, sysdep.c: Further optimize Ffuncall: -- process arg list at compiled-function creation time, converting into an array for extra-quick access at funcall time. -- rewrite funcall_compiled_function to use it, and inline this function. -- change the order of check for magic stuff in SPECBIND_FAST_UNSAFE to be faster. -- move the check for need to garbage collect into the allocation code, so only a single flag needs to be checked in funcall. buffer.c, symbols.c: add debug funs to check on mule optimization info in buffers and strings. eval.c, emacs.c, text.c, regex.c, scrollbar-msw.c, search.c: Fix evil crashes due to eistrings not properly reinitialized under pdump. Redo a bit some of the init routines; convert some complex_vars_of() into simple vars_of(), because they didn't need complex processing. callproc.c, emacs.c, event-stream.c, nt.c, process.c, process.h, sysdep.c, sysdep.h, syssignal.h, syswindows.h, ntproc.c: Delete. Hallelujah, praise the Lord, there is no god but Allah!!! fix so that processes can be invoked in bare temacs -- thereby eliminating any need for callproc.c. (currently only eliminated under NT.) remove all crufty and unnecessary old process code in ntproc.c and elsewhere. move non-callproc-specific stuff (mostly environment) into process.c, so callproc.c can be left out under NT. console-tty.c, doc.c, file-coding.c, file-coding.h, lstream.c, lstream.h: fix doc string handling so it works with Japanese, etc docs. change handling of "character mode" so callers don't have to manually set it (quite error-prone). event-msw.c: spacing fixes. lread.c: eliminate unused crufty vintage-19 "FSF defun hack" code. lrecord.h: improve pdump description docs. buffer.c, ntheap.c, unexnt.c, win32.c, emacs.c: Mule-ize some unexec and startup code. It was pseudo-Mule-ized before by simply always calling the ...A versions of functions, but that won't cut it -- eventually we want to be able to run properly even if XEmacs has been installed in a Japanese directory. (The current problem is the timing of the loading of the Unicode tables; this will eventually be fixed.) Go through and fix various other places where the code was not Mule-clean. Provide a function mswindows_get_module_file_name() to get our own name without resort to PATH_MAX and such. Add a big comment in main() about the problem with Unicode table load timing that I just alluded to. emacs.c: When error-checking is enabled (interpreted as "user is developing XEmacs"), don't ask user to "pause to read messages" when a fatal error has occurred, because it will wedge if we are in an inner modal loop (typically when a menu is popped up) and make us unable to get a useful stack trace in the debugger. text.c: Correct update_entirely_ascii_p_flag to actually work. lisp.h, symsinit.h: declarations for above changes.
author ben
date Sun, 14 Apr 2002 12:43:31 +0000
parents 026c5bf9c134
children 6728e641994e
line wrap: on
line diff
--- a/src/symsinit.h	Sat Apr 13 20:44:53 2002 +0000
+++ b/src/symsinit.h	Sun Apr 14 12:43:31 2002 +0000
@@ -35,8 +35,12 @@
 void init_win32_very_early (void);
 void init_mswindows_dde_very_early (void);
 
-/* Early Lisp-engine initialization (dump-time only for init,
-   dump-time and post-pdump-load-time for reinit). */
+/* Early Lisp-engine initialization -- dump-time only for init, dump-time
+   and post-pdump-load-time for reinit.  We call the reinit() routine
+   ourselves at post-pdump-load-time, but the init_() routine calls the
+   reinit() routine itself. (This is because sometimes the timing of when
+   to call the routine is tricky -- the init routine might need to do some
+   stuff, call the reinit() routine, and do some more stuff.) */
 
 void init_alloc_once_early (void);
 void reinit_alloc_once_early (void);
@@ -47,6 +51,18 @@
 void init_opaque_once_early (void);
 void init_elhash_once_early (void);
 void init_eistring_once_early (void);
+void reinit_eistring_once_early (void);
+
+/* Reset the Lisp engine.  Called both at dump-time, run-time and
+   run-temacs-time; at dump-time, it's called early, before any of the
+   vars() or complex_vars() routines.  Currently does almost nothing. */
+
+void init_alloc_early (void);
+
+/* Called somewhat randomly -- at dump-time, in the middle of the vars()
+   calls, and at run-time, just before the late initializations. */
+
+void init_eval_semi_early (void);
 
 /* Declare the built-in symbols and primitives (dump-time only). */
 
@@ -276,7 +292,6 @@
 void reinit_vars_of_buffer (void);
 void vars_of_bytecode (void);
 void vars_of_callint (void);
-void vars_of_callproc (void);
 void vars_of_chartab (void);
 void vars_of_cmdloop (void);
 void vars_of_cmds (void);
@@ -373,7 +388,6 @@
 void vars_of_mule_wnn (void);
 void reinit_vars_of_mule_wnn (void);
 void vars_of_nt (void);
-void vars_of_ntproc (void);
 void vars_of_objects (void);
 void reinit_vars_of_objects (void);
 void vars_of_objects_tty (void);
@@ -388,6 +402,7 @@
 void vars_of_profile (void);
 void vars_of_ralloc (void);
 void vars_of_redisplay (void);
+void vars_of_regex (void);
 void vars_of_scrollbar_x (void);
 void reinit_vars_of_scrollbar_x (void);
 void vars_of_scrollbar (void);
@@ -435,8 +450,6 @@
    #### The reinit_() functions should be called from emacs.c, not the
    corresponding complex_vars_of_(). */
 
-void complex_vars_of_regex (void);
-void complex_vars_of_search (void);
 void complex_vars_of_faces (void);
 void complex_vars_of_mule_charset (void);
 void complex_vars_of_file_coding (void);
@@ -447,7 +460,6 @@
 void complex_vars_of_alloc (void);
 void complex_vars_of_menubar (void);
 void complex_vars_of_scrollbar (void);
-void complex_vars_of_scrollbar_mswindows (void);
 void complex_vars_of_frame (void);
 void complex_vars_of_casetab (void);
 void complex_vars_of_syntax (void);
@@ -461,28 +473,19 @@
 void reinit_complex_vars_of_minibuf (void);
 void complex_vars_of_keymap (void);
 
-/* Reset the Lisp engine.  Called both at dump-time and run-time;
-   at dump-time, it's called early, before any of the vars() or
-   complex_vars() routines. */
-
-void init_alloc_early (void);
-void init_eval_early (void);
-
 /* Late initialization -- stuff pertaining only to interactive usage,
    I/O, or Lisp reading. (Dump-time and run-time, but the code itself
    may conditionalize on this by checking the `initialized' variable.) */
 
 void init_buffer_1 (void);
 void init_buffer_2 (void);
-void init_callproc (void);
 void init_console_stream (int reinit);
 void init_device_tty (void);
 void init_editfns (void);
-void init_environment (void);
 void init_event_Xt_late (void);
+void init_event_mswindows_late (void);
 void init_event_stream (void);
 void init_event_tty_late (void);
-void init_event_mswindows_late (void);
 void init_event_unixoid (void);
 void init_file_coding (void);
 void init_hpplay (void);
@@ -490,15 +493,15 @@
 void init_intl_win32 (void);
 void init_lread (void);
 void init_macros (void);
+void init_mswindows_environment (void);
 void init_mule_charset (void);
-void init_ntproc (void); /* #### delete me, please! */
-/* Not named init_process in order to avoid conflict with NS 3.3 */
-void init_xemacs_process (void);
+void init_nt (void);
 void init_postgresql_from_environment (void);
 void init_redisplay (void);
 void init_select_mswindows (void);
 void init_sunpro (void);
 void init_win32 (void);
+void init_xemacs_process (void);
 
 void syms_of_device_gtk (void);
 void syms_of_dialog_gtk (void);